{% load staticfiles %}
<link rel="stylesheet" media="screen, projection" href="{% static 'codemirror2/addon/display/fullscreen.css' %}" />
<link rel="stylesheet" media="screen, projection" href="{% static 'codemirror2/theme/blackboard.css' %}" />
<script src="{% static 'codemirror2/addon/display/fullscreen.js' %}"></script>
<script src="{% static 'codemirror2/addon/search/match-highlighter.js' %}"></script>
<script src="{% static 'codemirror2/addon/search/searchcursor.js' %}"></script>
<script src="{% static 'codemirror2/addon/selection/active-line.js' %}"></script>
<script src="{% static 'codemirror2/keymap/vim.js' %}"></script>
<script src="{% static 'codemirror2/keymap/emacs.js' %}"></script>
<script src="{% static 'codemirror2/addon/edit/closetag.js' %}"></script>
<script src="{% static 'codemirror2/addon/fold/xml-fold.js' %}"></script>
<script type="text/javascript">
    var elem = document.getElementById("id_content");
    var elmirror = CodeMirror.fromTextArea(elem, {{ options|safe }});
	elmirror.setSize(1130, 810);
</script>


